/* Seeed Grove ++ (C) 2015-2016 Stephane Charette <stephanecharette@gmail.com>
 * $Id: sg_MotionSensing.hpp 1866 2016-05-28 04:22:15Z stephane $
 */

#pragma once

// Central include file for SeeedGrove++ is "sg++.hpp".

// http://www.seeedstudio.com/wiki/Grove_System#Motion_Sensing

#include "sg_101020034_3AxisCompass.hpp"
